using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using DataDynamics.Analysis.Layout;

namespace FilterExtraction
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.rdDataSource1.ConnectionType = DataDynamics.Analysis.DataSources.ConnectionType.OleDb;
            this.rdDataSource1.ConnectionString = "Provider=Microsoft.Jet.OLEDB.4.0;Data Source=" + Environment.GetFolderPath(Environment.SpecialFolder.MyDocuments) + @"\Data Dynamics\Analysis\DataSources\NWind\nwind.mdb;";
            this.rdDataSource1.QueryString = @"SELECT c.CategoryName, p.ProductName, o.OrderID, o.OrderDate, d.UnitPrice, d.Quantity, s.Country AS SupplierCountry,
				s.City AS SupplierCity, s.CompanyName AS SupplierCompany, m.Country AS CustomerCountry, m.City AS CustomerCity,
				m.CompanyName AS CustomerCompany, d.Discount, m.Region AS CustomerRegion, s.Region AS SupplierRegion, e.LastName,
				e.EmployeeID AS EmployeeID, e.Title AS EmployeeTitle, e.Region AS EmployeeRegion, e.Country AS EmployeeCountry,
				e.City AS EmployeeCity, o.Freight, o.ShipName, o.ShipVia, o.ShipCity, o.ShipRegion, o.ShipCountry
				FROM Suppliers AS s INNER JOIN ((Categories AS c INNER JOIN Products AS p ON c.CategoryID = p.CategoryID)
				INNER JOIN (Employees AS e INNER JOIN (Customers AS m INNER JOIN (Orders AS o INNER JOIN [Order Details] AS d
				ON (o.OrderID = d.OrderID) AND (o.OrderID = d.OrderID) AND (o.OrderID = d.OrderID)) ON m.CustomerID = o.CustomerID)
				ON e.EmployeeID = o.EmployeeID) ON p.ProductID = d.ProductID) ON s.SupplierID = p.SupplierID";
            this.rdDataSource1.CustomSchemaFile = Environment.GetFolderPath(Environment.SpecialFolder.MyDocuments) + @"\Data Dynamics\Analysis\DataSources\NWind\NwindMDB-SalesProductsSuppliers.schema";

            this.pivotView1.DataSource = this.rdDataSource1;
            this.rdDataSource1.Connect();
        }

        private void ExtractFilters_Click(object sender, EventArgs e)
        {
            ILayoutState layout = pivotView1.GetLayoutState();
            FilterOutput fo = new FilterOutput();
            if (layout.Filters.Count > 0)
            {
                foreach (IFieldFilter filter in layout.Filters)
                {
                    fo.AddLine("" + filter.FieldUniqueName);
                    if (filter is IHeadingFilter)
                    {
                        IHeadingFilter headingFilter = (IHeadingFilter)filter;

                        switch (headingFilter.FilterType)
                        {
                            case HeadingFilterType.BeginsWith:
                                fo.AddLine("Heading begins with: " + headingFilter.Value);
                                break;
                            case HeadingFilterType.Between:
                                fo.AddLine("Heading is between {0} and {1}", headingFilter.Value, headingFilter.EndValue);
                                break;
                            case HeadingFilterType.BetweenExclusive:
                                fo.AddLine("Heading is between but not equal to {0} and {1}", headingFilter.Value, headingFilter.EndValue);
                                break;
                            case HeadingFilterType.Contains:
                                fo.AddLine("Heading Contains the value " + headingFilter.Value);
                                break;
                            case HeadingFilterType.EndsWith:
                                fo.AddLine("Heading ends with " + headingFilter.Value);
                                break;
                            case HeadingFilterType.Equals:
                                fo.AddLine("Heading equals " + headingFilter.Value);
                                break;
                            case HeadingFilterType.From:
                                fo.AddLine("Heading is From " + headingFilter.Value);
                                break;
                            case HeadingFilterType.FromExclusive:
                                fo.AddLine("Heading is from but not equal to " + headingFilter.Value);
                                break;
                            case HeadingFilterType.None:
                                fo.AddLine("Apparantly, no heading filter has been applied.");
                                break;
                            case HeadingFilterType.Not:
                                fo.AddLine("Heading is not " + headingFilter.Value);
                                break;
                            case HeadingFilterType.NotBeginsWith:
                                fo.AddLine("Heading does not begin with " + headingFilter.Value);
                                break;
                            case HeadingFilterType.NotBetween:
                                fo.AddLine("Heading is not between {0} and {1}", headingFilter.Value, headingFilter.EndValue);
                                break;
                            case HeadingFilterType.NotContains:
                                fo.AddLine("Heading does not contain " + headingFilter.Value);
                                break;
                            case HeadingFilterType.NotEndsWith:
                                fo.AddLine("Heading does not end with " + headingFilter.Value);
                                break;
                            case HeadingFilterType.NotEquals:
                                fo.AddLine("Heading is not equal to " + headingFilter.Value);
                                break;
                            case HeadingFilterType.To:
                                fo.AddLine("Heading is less than " + headingFilter.Value);
                                break;
                            case HeadingFilterType.ToExclusive:
                                fo.AddLine("Heading is less than but not equal to " + headingFilter.Value);
                                break;
                            default:
                                fo.AddLine("No heading filter type specified");
                                break;
                        }
                    }
                    if (filter is IValueFilter)
                    {
                        IValueFilter valueFilter = (IValueFilter)filter;
                        switch (valueFilter.FilterType)
                        {
                            case ValueFilterType.Between:
                                fo.AddLine("Field filtered where {0} is between {1} and {2}", valueFilter.Expression, valueFilter.Value, valueFilter.EndValue);
                                break;
                            case ValueFilterType.Equals:
                                fo.AddLine("Field filtered where {0} equals {1}", valueFilter.Expression, valueFilter.Value);
                                break;
                            case ValueFilterType.LargerThan:
                                fo.AddLine("Field filtered where {0} is greater than {1}", valueFilter.Expression, valueFilter.Value);
                                break;
                            case ValueFilterType.LargerThanOrEqual:
                                fo.AddLine("Field filtered where {0} is greateer than or equal to {1}", valueFilter.Expression, valueFilter.Value);
                                break;
                            case ValueFilterType.NotBetween:
                                fo.AddLine("Field filtered where {0} values are not between {1} and {2}", valueFilter.Expression, valueFilter.Value, valueFilter.EndValue);
                                break;
                            case ValueFilterType.NotEquals:
                                fo.AddLine("Field filtered where {0} does not equal {1}", valueFilter.Expression, valueFilter.Value);
                                break;
                            case ValueFilterType.SmallerThan:
                                fo.AddLine("Field filtered where {0} is less than{1}", valueFilter.Expression, valueFilter.Value);
                                break;
                            case ValueFilterType.SmallerThanOrEqual:
                                fo.AddLine("Field filtered where {0} is less than or equal to {1}", valueFilter.Expression, valueFilter.Value);
                                break;
                            default:
                                fo.AddLine("Apparantly, no filter is applied");
                                break;
                        }
                    }
                    if (filter is ITopNFilter)
                    {
                        ITopNFilter topNFilter = (ITopNFilter)filter;
                        switch (topNFilter.FilterType)
                        {
                            case TopValueFilterType.BottomCount:
                                fo.AddLine("Field filtered based on the bottom {1} count of {0}", topNFilter.Expression, topNFilter.Value);
                                break;
                            case TopValueFilterType.BottomPercent:
                                fo.AddLine("Field filtered based on the bottom {1} percent of {0}", topNFilter.Expression, topNFilter.Value);
                                break;
                            case TopValueFilterType.BottomSum:
                                fo.AddLine("Field filtered based on the bottom {1} sum of {0}", topNFilter.Expression, topNFilter.Value);
                                break;
                            case TopValueFilterType.None:
                                fo.AddLine("Filter is empty");
                                break;
                            case TopValueFilterType.TopCount:
                                fo.AddLine("Field filtered based on the top {1} count of {0}", topNFilter.Expression, topNFilter.Value);
                                break;
                            case TopValueFilterType.TopPercent:
                                fo.AddLine("Field filtered based on the top {1} percent of {0}", topNFilter.Expression, topNFilter.Value);
                                break;
                            case TopValueFilterType.TopSum:
                                fo.AddLine("Field filtered based on the top {1} sum of {0}", topNFilter.Expression, topNFilter.Value);
                                break;
                            default:
                                fo.AddLine("Apparantly, no filter is applied");
                                break;
                        }
                    }
                    if (filter is IRangeFilter)
                    {
                        IRangeFilter rangeFilter = (IRangeFilter)filter;
                        fo.AddLine("Filtered between {0} and {1}", rangeFilter.StartValue, rangeFilter.EndValue);
                    }
                    if (filter is IMemberFilter)
                    {
                        IMemberFilter memberFilter = (IMemberFilter)filter;
                        foreach (DataDynamics.Analysis.Schema.Member m in memberFilter.RootMembers)
                        {
                            if (memberFilter.IsMemberIncluded(m))
                            {
                                fo.AddLine("Member " + m.UniqueName + " is included");
                            }
                        }
                    }
                }
                fo.ShowDialog(this);
            }
            else
            {
                MessageBox.Show("No filters have been applied", "No filters", MessageBoxButtons.OK, MessageBoxIcon.Information);
            }
        }
            
    }
}